@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include "articleviewer-ng/webengine/articleviewerwebengine.h"
 
 class KActionCollection;
-namespace Akregator {
+namespace Akregator
+{
 class AkrWebEngineViewer : public ArticleViewerWebEngine
 {
     Q_OBJECT
