@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef URLHANDLERWebEngineMANAGER_H
 #define URLHANDLERWebEngineMANAGER_H
 
+#include "akregator_export.h"
 #include <QObject>
 #include <QVector>
-#include "akregator_export.h"
 
-namespace Akregator {
+namespace Akregator
+{
 class URLHandlerWebEngine;
 class ArticleViewerWebEngine;
 class AKREGATOR_EXPORT URLHandlerWebEngineManager : public QObject
