@@ -12,14 +12,12 @@
 #include <QSortFilterProxyModel>
 #include <QVector>
 
-namespace Akregator {
+namespace Akregator
+{
 class FilterColumnsProxyModel : public QSortFilterProxyModel
 {
 public:
-    enum Mode {
-        Blacklist,
-        Whitelist
-    };
+    enum Mode { Blacklist, Whitelist };
 
     explicit FilterColumnsProxyModel(QObject *parent = nullptr);
 
